Welcom to ``ibm-wmla-client``
-------------------------------

``ibm-wmla-client`` is a python based client to simplify using Watson Machine Learning Accelerator Elastic Distributed Inference (WMLA EDI).

Prerequisites
--------------------
+ Python 3.5.3 or above
+ `ibm_wmla`_ 0.1.0 or above

.. _ibm_wmla: https://pypi.org/project/ibm-wmla/

